/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file EnumAdjustmentType.h

  \ingroup layout
*/

#ifndef __TERRALIB_LAYOUT_INTERNAL_ENUM_ADJUSTMENT_TYPE_H 
#define __TERRALIB_LAYOUT_INTERNAL_ENUM_ADJUSTMENT_TYPE_H 

// TerraLib
#include "AbstractEnum.h"
#include "../Config.h"

namespace te
{
  namespace layout
  {
    class EnumType;

    class TELAYOUTEXPORT EnumAdjustmentType : public AbstractEnum
    {
      public:

        /*!
          \brief Constructor
        */
        EnumAdjustmentType();

        /*!
          \brief Destructor
        */ 
        virtual ~EnumAdjustmentType();

        /*!
          \brief Returns value that represents none type belonging to enumeration.
      
          \return enum value      
        */
        virtual EnumType* getNoneType() const;
        
        /*!
          \brief Returns value that represents reduce type adjust type belonging to enumeration.
      
          \return enum value      
        */
        virtual EnumType* getReduceTextAdjustmentType() const;

        /*!
          \brief Returns value that represents resize shape adjust type belonging to enumeration.

          \return enum value
        */
        virtual EnumType* getResizeShapeAdjustmentType() const;
            
      protected:

        /*!
          \brief Reimplemented from AbstractEnum
        */
        virtual void init();

      protected:

        EnumType* m_noneType; //!< value that represents none type belonging to enumeration
        EnumType* m_reduceTextAdjustment; //!< value that represents adjust reduce text type belonging to enumeration
        EnumType* m_resizeShapeAdjustment; //!< value that represents adjust resize shape type belonging to enumeration 
    };
  }
}

#endif
