/*  Copyright (C) 2001-2014 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file ImageGalleryDialogModel.h
   
  \brief Image gallery window model.

  \ingroup layout
*/

#ifndef __TERRALIB_LAYOUT_INTERNAL_IMAGE_GALLERY_DIALOG_MODEL_H 
#define __TERRALIB_LAYOUT_INTERNAL_IMAGE_GALLERY_DIALOG_MODEL_H

// TerraLib
#include "../core/pattern/mvc/AbstractOutsideModel.h"
#include "../core/Config.h"
#include "../core/property/Property.h"

// STL
#include <vector>
#include <list>

namespace te
{
  namespace layout
  {
    class Properties;
    /*!
      \brief Image gallery window model.

      \ingroup layout
    */
    class TELAYOUTEXPORT ImageGalleryDialogModel : public AbstractOutsideModel
    {
    public:

      /*!
        \brief Constructor
      */
      ImageGalleryDialogModel();

      /*!
        \brief Destructor
      */
      virtual ~ImageGalleryDialogModel();

      /*!
        \brief Reimplemented from AbstractOutsideModel
      */
      virtual void updateProperties(te::layout::Properties* properties, bool notify = true);

      /*!
        \brief Reimplemented from AbstractOutsideModel
      */
      virtual Properties* getProperties() const;

      /*!
        \brief Set current property that call the window

        \param property current property
      */
      virtual void setPathsProperty(Property property);

      /*!
        \brief Get sub properties of the current property.

        \return sub properties
      */
      virtual std::vector<std::string> getPaths();
          
    protected:

      Property m_svgProperty; //!< current property that call the window

    };
  }
}

#endif

