/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file SharedIOAccess.h
   
  \brief Centralized control of signal emission for I/O access. Controls how many they requested, 
   and only emits a signal to close the access, when there is no more object using.

  \ingroup layout
*/

#ifndef __TERRALIB_LAYOUT_INTERNAL_SHARED_IO_ACCESS_H
#define __TERRALIB_LAYOUT_INTERNAL_SHARED_IO_ACCESS_H

// TerraLib
#include "../../core/Config.h"

#include <QObject>

namespace te
{
  namespace layout
  {
    /*!
    \brief Centralized control of signal emission for I/O access. Controls how many they requested, 
     and only emits a signal to close the access, when there is no more object using.
    
    \ingroup layout
    */
    class TELAYOUTEXPORT SharedIOAccess : public QObject
    {
      Q_OBJECT //for slots/signals
        
      public:

        /*!
          \brief Constructor
        */
        SharedIOAccess();

        /*!
          \brief Destructor
        */
        virtual ~SharedIOAccess();

        /*!
          \brief Warns that the application will access the disk.
        */
        virtual void emitRequestIOEnterAccess();

        /*!
          \brief Warns that the application already finishes accessing the disk.
        */
        virtual void emitRequestIOEndAccess();

      signals:

        /*!
          \brief Sends the signal that the application will access the disk.
        */
        void requestIOEnterAccess();

        /*!
          \brief Sends the signal that the application has finished accessing the disk.
        */
        void requestIOEndAccess();

      protected:

        int m_accessCount; //!< access requisition counter
    };
  }
}

#endif 
