/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

This file is part of the TerraLib - a Framework for building GIS enabled applications.

TerraLib is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

TerraLib is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with TerraLib. See COPYING. If not, write to
TerraLib Team at <terralib-team@terralib.org>.
*/

/*!
  \file ImageController.h

  \brief Class that represents Image Item controller.
  \ingroup layout
*/

#ifndef __TERRALIB_LAYOUT_INTERNAL_IMAGE_CONTROLLER_H
#define __TERRALIB_LAYOUT_INTERNAL_IMAGE_CONTROLLER_H

// TerraLib
#include "../../core/Config.h"
#include "../../core/pattern/mvc/AbstractItemController.h"

class QString;

namespace te
{
  namespace layout
  {
    class AbstractItemModel;
    class Properties;
    /*!
      \brief Class that represents Image Item controller.

      \ingroup layout

      \sa te::layout::AbstractItemController
    */
    class TELAYOUTEXPORT ImageController : public AbstractItemController
    {
     public:

       /*!
       \brief Constructor

         \param model "Model" part of MVC component
         \param view "View" part of MVC component
       */
       ImageController(AbstractItemModel* model, AbstractItemView* view);

       /*!
         \brief Destructor
       */
       virtual ~ImageController();

       /*!
         \brief Sets the new values of the given properties

         \param properties new values
       */
      virtual void setProperties(const Properties& properties);

      /*!
        \brief Calculates the best aspect ratio between width and height for a Svg file and updates properties.

        \param filePath file path
      */
      void calculateSVGRect(const QString& filePath);

      /*!
        \brief Get file extension.

        \return properties set of properties to search file extension
      */
      QString getFileExtension(const Properties& properties);

     protected:
       
       /*!
         \brief Calculates the best aspect ratio between width and height and updates properties.

         \return properties set of properties to search for changes
       */
       virtual void configImageSettings(const Properties& properties);  
    };
  }
}

#endif //__TERRALIB_LAYOUT_INTERNAL_IMAGE_CONTROLLER_H
