/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/common/MathUtils.h

  \brief Math utils.

  \ingroup common
*/

#ifndef __TERRALIB_COMMON_INTERNAL_MATHUTILS_H
#define __TERRALIB_COMMON_INTERNAL_MATHUTILS_H

// TerraLib
#include "Config.h"

namespace te
{
  namespace common
  {
    /*!
      \brief Round a value.

      \param val The input value.

      \return A rounded value.
    */
     template<typename InputValueT, typename OutputValueT> 
     inline OutputValueT Round(const InputValueT& inVal)
     {
       return (OutputValueT)( ( inVal >= 0 ) ? (inVal + 0.5) : (inVal - 0.5) );
     }

  }     // end namespace common
}       // end namespace te

#endif  //__TERRALIB_COMMON_INTERNAL_MATHUTILS_H
