/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
 \file terralib/qt/widgets/rp/SensorManagerDialog.h
 
 \brief A dialog used to manage Spectral Sensors.
 */

#ifndef __TERRALIB_SRS_INTERNAL_QT_SENSORMANAGERDIALOG_H
#define __TERRALIB_SRS_INTERNAL_QT_SENSORMANAGERDIALOG_H

// TerraLib
#ifndef Q_MOC_RUN
#include "../../../rp/Functions.h"
#endif
#include "../Config.h"

// Qt
#include <QDialog>
#include <QStringList>
#include <QTableWidgetItem>
#include <QTreeWidgetItem>

//STL
#include <string>

// Forward declaraion
namespace Ui { class SensorManagerDialogForm; }

namespace te
{
  namespace qt
  {
    namespace widgets
    {
      
      /*!
       \class SensorManagerDialog
       
       \brief A dialog used to build a SensorManagerDialog element.

       \ingroup widgets
      */
      class TEQTWIDGETSEXPORT SensorManagerDialog : public QDialog
      {
        Q_OBJECT
        
      public:
        
        /*! 
         \brief Constructs a basic dialog which is a child of parent, with widget flags set to f.
         \param parent Pointer to the dialog parent.
         \param f The dialog flags.
         */
        SensorManagerDialog( QWidget* parent = 0, Qt::WindowFlags f = 0);
        
        /*! 
         \brief Destructor. 
         */
        ~SensorManagerDialog();
     
        /*!
         \brief Returns the selected sensor name. 
         */
        const QString& getSelectedSensor() const;
       
        ///*!
        //\brief Returns the selected sensor paramters.
        //*/
        //const te::rp::SpectralSensorParams& getSelectedSensorParams() const;

        bool isModified() { return m_modified; }

        void updateSensorParams();

      protected slots:

        void onSensorTableWidgetItemClicked(QTableWidgetItem*);
        void onSensorTableWidgetItemChanged(QTableWidgetItem*);
        void onSavePushButtonClicked();
        void onOkPushButtonClicked();
        void onCancelPushButtonClicked();
        void onHelpPushButtonClicked();
        void onSearchLineEditTextChanged(const QString& text);
        void onAddToolButtonClicked();
        
      private:
        void filter(const QList<QTableWidgetItem*>& items);
        
        Ui::SensorManagerDialogForm* m_ui;         //!< Dialog form.    

        QString m_sensorselected; //!< Selected sensor name
        bool m_edited; //!< Flag to indicate if sensors were edited
        bool m_modified;
        std::map<std::string, te::rp::SpectralSensorParams > m_Params;
      };
    } // end namespace widgets
  }   // end namespace qt
}     // end namespace te

#endif  // __TERRALIB_SRS_INTERNAL_QT_SENSORMANAGERDIALOG_H
