#
#  Copyright (C) 2008-2014 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#
#  Description: CMake Package Configuration File for the install-tree.
#
#  Author: Gilberto Ribeiro de Queiroz <gribeiro@dpi.inpe.br>
#          Juan P. Garrido <juan@dpi.inpe.br>
#          Frederico Augusto T. Bede <frederico.bede@funcate.org.br>
#

get_filename_component(_dir "${CMAKE_CURRENT_LIST_FILE}" PATH)
get_filename_component(_prefix "${_dir}/../../../" ABSOLUTE)

include("${_prefix}/lib/cmake/terralib-5.2.3/terralib-exports.cmake")

set(terralib_INCLUDE_DIRS "${_prefix}/include")

# Modules compiled 
# This code is used to verify the compiled components.
set (TERRALIB_MODULES core;cellspace;classification;color;common;dataaccess;datatype;filter;geometry;gml;graph;maptools;metadata;memory;attributefill_core;attributefill_qt;qt_apf;qt_widgets;raster;rp;sa_core;sam;srs;st;statistics_core;stmemory;statistics_qt;symbology;vp_core;vp_qt;sa_qt;xlink;xml;edit_core;edit_qt;mnt_core;mnt_qt;ws_core;ws_ogc_wcs_client;ws_ogc_wcs_qt;ws_ogc_wms_client;ws_ogc_wms_qt)

# This code is used to verify the compiled plugins.
set (TE_PLUGINS gdal;ogr;postgis;qt_plugins_cellspace;qt_plugins_datasource_gdal;qt_plugins_datasource_ogr;qt_plugins_datasource_pgis;qt_plugins_datasource_wfs;qt_plugins_attributefill;qt_plugins_vp;qt_plugins_rp;qt_plugins_sa;qt_plugins_wtss;wfs;qt_plugins_edit;qt_plugins_mnt;ws_ogc_wcs_dataaccess;ws_ogc_wcs_qt_plugin;ws_ogc_wms_dataaccess;ws_ogc_wms_qt_plugin)

list (APPEND TERRALIB_MODULES "${TE_PLUGINS}")

set (TERRALIB_LIBRARIES "")

foreach (comp ${TE_PLUGINS})
  list(APPEND TERRALIB_PLUGINS terralib_mod_${comp})
endforeach()

if (terralib_FIND_COMPONENTS)
  foreach (comp ${terralib_FIND_COMPONENTS})
    list (FIND TERRALIB_MODULES ${comp} cmp_found)
    if (cmp_found EQUAL "-1") # Does not found component
      set (terralib_${comp}_FOUND 0)
      if(terralib_FIND_REQUIRED_${comp})
        message(SEND_ERROR "TerraLib ${comp} not available.")
      endif()
    else()                    # Found component.
      set(terralib_mod_${comp}_FOUND 1)
      message("TerraLib module ${comp} available.")
      list (APPEND TERRALIB_LIBRARIES terralib_mod_${comp})
    endif()
  endforeach()
endif() 

get_filename_component(CURRENT_DIR ${CMAKE_CURRENT_LIST_FILE} PATH)
include ( ${CURRENT_DIR}/terralib_macros.cmake )
